searchData={"items":[{"type":"module","title":"Scrypt","doc":"This module provides the base functionality to work with the Scrypt KDF.","ref":"Scrypt.html"},{"type":"function","title":"Scrypt.hash/6","doc":"Creates an Scrypt hash from the given parameters, allowing a custom salt\nand key length.","ref":"Scrypt.html#hash/6"},{"type":"function","title":"Examples - Scrypt.hash/6","doc":"iex> Scrypt.hash(\"hunter2\", \"oftheearth\", 14, 8, 1, 64)\n     >","ref":"Scrypt.html#hash/6-examples"},{"type":"function","title":"Scrypt.kdf/4","doc":"Generates an Scrypt header from the given parameters, using 32 bytes\nhash and a 64 bytes key length. If a salt is not given, one is generated with\n:crypto.strong_rand_bytes(n :: non_neg_integer())","ref":"Scrypt.html#kdf/4"},{"type":"function","title":"Examples - Scrypt.kdf/4","doc":"iex> Scrypt.kdf(\"hunter2\", 14, 8, 1)\n     >\n\n    iex> Scrypt.kdf(\"hunter2\", :crypto.strong_rand_bytes(32), 14, 8, 1)\n     >","ref":"Scrypt.html#kdf/4-examples"},{"type":"function","title":"Scrypt.kdf/5","doc":"","ref":"Scrypt.html#kdf/5"},{"type":"function","title":"Scrypt.secure_compare/2","doc":"Copied from: https://github.com/elixir-plug/plug/blob/v1.5.0-rc.2/lib/plug/crypto.ex#L102\n\nCompares the two binaries in constant-time to avoid timing attacks.\nSee: http://codahale.com/a-lesson-in-timing-attacks/","ref":"Scrypt.html#secure_compare/2"},{"type":"function","title":"Scrypt.verify?/6","doc":"Verifies an Scrypt hash.","ref":"Scrypt.html#verify?/6"},{"type":"function","title":"Examples - Scrypt.verify?/6","doc":"iex(1)> hash = Scrypt.hash(\"hunter2\", \"oftheearth\", 14, 8, 1, 64)\n     >\n    iex(2)> Scrypt.verify?(hash, \"hunter2\", \"oftheearth\", 14, 8, 1)\n    true","ref":"Scrypt.html#verify?/6-examples"},{"type":"function","title":"Scrypt.verify_kdf?/2","doc":"Decodes and verifies an Scrypt header using a supplied password,\nfollowing the documented specs.\n\n```plain\n+----------+--------+----------------------------------------------------------+\n|   offset | length |                        assignment                        |\n+----------+--------+----------------------------------------------------------+\n|   0      | 6      | \"scrypt\"                                                 |\n|   6      | 1      | scrypt data file version number (== 0)                   |\n|   7      | 1      | log2(N) (must be between 1 and 63 inclusive)             |\n|   8      | 4      | r (big-endian integer; must satisfy r * p < 2^30)        |\n|   12     | 4      | p (big-endian integer; must satisfy r * p < 2^30)        |\n|   16     | 32     | salt                                                     |\n|   48     | 16     | first 16 bytes of SHA256(bytes 0 .. 47)                  |\n|   64     | 32     | HMAC-SHA256(bytes 0 .. 63)                               |\n|   96     | X      | data xor AES256-CTR key stream generated with nonce == 0 |\n|   96+X   | 32     | HMAC-SHA256(bytes 0 .. 96 + (X - 1))                     |\n+----------+--------+----------------------------------------------------------+\n```","ref":"Scrypt.html#verify_kdf?/2"},{"type":"function","title":"Examples - Scrypt.verify_kdf?/2","doc":"iex(1)> header = Scrypt.kdf(\"hunter2\", 14, 8, 1)\n     >\n    iex(2)> Scrypt.verify_kdf?(header, \"hunter2\")\n    true","ref":"Scrypt.html#verify_kdf?/2-examples"},{"type":"module","title":"Scrypt.NIF","doc":"","ref":"Scrypt.NIF.html"},{"type":"function","title":"Scrypt.NIF.hash_nif/6","doc":"","ref":"Scrypt.NIF.html#hash_nif/6"},{"type":"function","title":"Scrypt.NIF.init/0","doc":"","ref":"Scrypt.NIF.html#init/0"},{"type":"extras","title":"ScryptElixir","doc":"# ScryptElixir\n\n[![ScryptElixir](https://circleci.com/gh/christianjgreen/scrypt_elixir.svg?style=shield)](https://circleci.com/gh/christianjgreen/scrypt_elixir)\n\nElixir wrapper for the Scrypt key derivation function. \nhttps://www.tarsnap.com/scrypt.html","ref":"readme.html"},{"type":"extras","title":"Usage - ScryptElixir","doc":"This library provides raw scrypt hashing functionality as well as an implementation of the original suggested KDF.\n\n* `hash/6` is a lower level function that allows for a custom salt length and derived key length. The result is the raw binary scrypt hash. This function allows for custom salts and derived key lengths.\n* `kdf/4` is a function that creates an Scrypt header that utilizes HMAC to ensure hash integrity. This implementation enforces a 32 byte salt length and 64 byte derived key length.\n* `kdf/5` creates an Scrypt header, but allows for a custom 32 byte salt.\n* `verify?/6` validates an Scrypt hash using the supplied parameters, returning a boolean.\n* `verify_kdf?/2` validates an Scrypt header using the supplied password.\n\nBoth functions rely on a core set of parameters:\n* `password` - the core binary being hashed\n* `salt` - a pseudo-randomly generated string of bytes used for hashing\n* `logN` - exponent for CPU/memory cost (2^logN)\n* `r` - blocksize","ref":"readme.html#usage"},{"type":"extras","title":"Installation - ScryptElixir","doc":"The package can be installed by adding `scrypt_elixir` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:scrypt_elixir, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be found at [https://hexdocs.pm/scrypt_elixir](https://hexdocs.pm/scrypt_elixir).","ref":"readme.html#installation"}],"content_type":"text/markdown"}